#version 330

// Saving output informations to our color attachments
layout(location = 0) out vec4 rayOrigin;
layout(location = 1) out vec4 rayDirection;

// Information about width and height of generated image
uniform float width;
uniform float height;
uniform float depth;

//----------------------------------------------------------------
// TODO:
// 1) Compute the normalized fragment coordinate in the range (-1,-1) to (1,1)
// 2) Compute the ray direction from the coordinate and the depth which sets field-of-view (FOV)
//----------------------------------------------------------------

void main()
{
	// Get ratio of width and height
	float ratio = width / height;

	// Get fragment coordinates and transform them to range from (-1,-1) to (1,1)
	vec2 fragCoord = gl_FragCoord.xy / vec2(width / 2.f, height / 2.f) - 1.f;
	
	// Multiple width part of transformed coordinates by ratio
	vec2 uv = fragCoord * vec2(ratio, 1.f);

	// Output ray origin (camera position in this case) and the initial reflection coefficient
	rayOrigin = vec4(0.f, 0.f, 8.f, 1.f);

	// Output ray direction, transformed coordinates in x, y and -depth from cpu in z coordinate, fourth component is ray length
	rayDirection = vec4(normalize(vec3(uv, -depth)), 1e38f);
}